@background: #ffffcc;

@modifier: #555;

@c1:  #408080 - @modifier;
@c2:  #FF0000 - @modifier;
@c3:  #008000 - @modifier;
@c4:  #666666 - @modifier;
@c5:  #BC7A00 - @modifier;
@c6:  #A00000 - @modifier;
@c7:  #000080 - @modifier;
@c8:  #00A000 - @modifier;
@c9:  #808080 - @modifier;
@c10: #800080 - @modifier;
@c11: #0040D0 - @modifier;
@c12: #B00040 - @modifier;
@c13: #BA2121 - @modifier;
@c14: #7D9029 - @modifier;
@c15: #0000FF - @modifier;
@c16: #880000 - @modifier;
@c17: #AA22FF - @modifier;
@c18: #999999 - @modifier;
@c19: #D2413A - @modifier;
@c20: #A0A000 - @modifier;
@c21: #19177C - @modifier;
@c22: #bbbbbb - @modifier;
@c23: #BB6622 - @modifier;
@c24: #BB6688 - @modifier;

div.highlight {
    .hll { background-color: @background }
    .c { color: @c1; font-style: italic } /* Comment */
    .err { border: 1px solid @c2 } /* Error */
    .k { color: @c3; font-weight: bold } /* Keyword */
    .o { color: @c4 } /* Operator */
    .cm { color: @c1; font-style: italic } /* Comment.Multiline */
    .cp { color: @c5 } /* Comment.Preproc */
    .c1 { color: @c1; font-style: italic } /* Comment.Single */
    .cs { color: @c1; font-style: italic } /* Comment.Special */
    .gd { color: @c6 } /* Generic.Deleted */
    .ge { font-style: italic } /* Generic.Emph */
    .gr { color: @c2 } /* Generic.Error */
    .gh { color: @c7; font-weight: bold } /* Generic.Heading */
    .gi { color: @c8 } /* Generic.Inserted */
    .go { color: @c9 } /* Generic.Output */
    .gp { color: @c7; font-weight: bold } /* Generic.Prompt */
    .gs { font-weight: bold } /* Generic.Strong */
    .gu { color: @c10; font-weight: bold } /* Generic.Subheading */
    .gt { color: @c11 } /* Generic.Traceback */
    .kc { color: @c3; font-weight: bold } /* Keyword.Constant */
    .kd { color: @c3; font-weight: bold } /* Keyword.Declaration */
    .kn { color: @c3; font-weight: bold } /* Keyword.Namespace */
    .kp { color: @c3 } /* Keyword.Pseudo */
    .kr { color: @c3; font-weight: bold } /* Keyword.Reserved */
    .kt { color: @c12 } /* Keyword.Type */
    .m { color: @c4 } /* Literal.Number */
    .s { color: @c13 } /* Literal.String */
    .na { color: @c14 } /* Name.Attribute */
    .nb { color: @c3 } /* Name.Builtin */
    .nc { color: @c15; font-weight: bold } /* Name.Class */
    .no { color: @c16 } /* Name.Constant */
    .nd { color: @c17 } /* Name.Decorator */
    .ni { color: @c18; font-weight: bold } /* Name.Entity */
    .ne { color: @c19; font-weight: bold } /* Name.Exception */
    .nf { color: @c15 } /* Name.Function */
    .nl { color: @c20 } /* Name.Label */
    .nn { color: @c15; font-weight: bold } /* Name.Namespace */
    .nt { color: @c3; font-weight: bold } /* Name.Tag */
    .nv { color: @c21 } /* Name.Variable */
    .ow { color: @c17; font-weight: bold } /* Operator.Word */
    .w { color: @c22 } /* Text.Whitespace */
    .mf { color: @c4 } /* Literal.Number.Float */
    .mh { color: @c4 } /* Literal.Number.Hex */
    .mi { color: @c4 } /* Literal.Number.Integer */
    .mo { color: @c4 } /* Literal.Number.Oct */
    .sb { color: @c13 } /* Literal.String.Backtick */
    .sc { color: @c13 } /* Literal.String.Char */
    .sd { color: @c13; font-style: italic } /* Literal.String.Doc */
    .s2 { color: @c13 } /* Literal.String.Double */
    .se { color: @c23; font-weight: bold } /* Literal.String.Escape */
    .sh { color: @c13 } /* Literal.String.Heredoc */
    .si { color: @c24; font-weight: bold } /* Literal.String.Interpol */
    .sx { color: @c3 } /* Literal.String.Other */
    .sr { color: @c24 } /* Literal.String.Regex */
    .s1 { color: @c13 } /* Literal.String.Single */
    .ss { color: @c21 } /* Literal.String.Symbol */
    .bp { color: @c3 } /* Name.Builtin.Pseudo */
    .vc { color: @c21 } /* Name.Variable.Class */
    .vg { color: @c21 } /* Name.Variable.Global */
    .vi { color: @c21 } /* Name.Variable.Instance */
    .il { color: @c4 } /* Literal.Number.Integer.Long */
}
